@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-from typing import Iterable, Optional, Tuple, TypeVar, Union
+from typing import Iterable, Optional, TypeVar, Union
 
 import tensorflow as tf
 import torch
