@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
-from typing import Optional, Tuple, Union
+from typing import Iterable, Optional, Tuple, Union
 
 from albumentations.augmentations.transforms import MaskDropout as MaskDropoutAlb
 
@@ -32,6 +32,8 @@ class MaskDropout(MultiVariateAlbumentation):
         mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
             regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
             like "!infer" or "!train".
+        ds_id: What dataset id(s) to execute this Op in. To execute regardless of ds_id, pass None. To execute in all
+            ds_ids except for a particular one, you can pass an argument like "!ds1".
         image_in: The key of an image to be modified.
         mask_in: The key of a mask to be modified (with the same random factors as the image).
         masks_in: The key of masks to be modified (with the same random factors as the image).
@@ -50,7 +52,8 @@ class MaskDropout(MultiVariateAlbumentation):
                  max_objects: Union[int, Tuple[int, int]] = 1,
                  image_fill_value: Union[int, float, str] = 0,
                  mask_fill_value: Union[int, float] = 0,
-                 mode: Optional[str] = None,
+                 mode: Union[None, str, Iterable[str]] = None,
+                 ds_id: Union[None, str, Iterable[str]] = None,
                  image_in: Optional[str] = None,
                  mask_in: Optional[str] = None,
                  masks_in: Optional[str] = None,
@@ -74,4 +77,5 @@ class MaskDropout(MultiVariateAlbumentation):
             keypoints_out=None,
             bbox_params=None,
             keypoint_params=None,
-            mode=mode)
+            mode=mode,
+            ds_id=ds_id)
