@@ -30,6 +30,8 @@ class RandomFog(ImageOnlyAlbumentation):
         mode: What mode(s) to execute this Op in. For example, "train", "eval", "test", or "infer". To execute
             regardless of mode, pass None. To execute in all modes except for a particular one, you can pass an argument
             like "!infer" or "!train".
+        ds_id: What dataset id(s) to execute this Op in. To execute regardless of ds_id, pass None. To execute in all
+            ds_ids except for a particular one, you can pass an argument like "!ds1".
         fog_coef_lower: Lower limit for fog intensity coefficient. Should be in the range [0, 1].
         fog_coef_upper: Upper limit for fog intensity coefficient. Should be in the range [0, 1].
         alpha_coef: Transparency of the fog circles. Should be in the range [0, 1].
@@ -41,6 +43,7 @@ class RandomFog(ImageOnlyAlbumentation):
                  inputs: Union[str, Iterable[str]],
                  outputs: Union[str, Iterable[str]],
                  mode: Union[None, str, Iterable[str]] = None,
+                 ds_id: Union[None, str, Iterable[str]] = None,
                  fog_coef_lower: float = 0.3,
                  fog_coef_upper: float = 1.0,
                  alpha_coef: float = 0.08):
@@ -51,4 +54,5 @@ class RandomFog(ImageOnlyAlbumentation):
                          always_apply=True),
             inputs=inputs,
             outputs=outputs,
-            mode=mode)
+            mode=mode,
+            ds_id=ds_id)
