@@ -17,8 +17,8 @@ import multiprocessing
 import os
 import sqlite3 as sql
 import sys
-import threading
 import traceback
+from collections import defaultdict
 from contextlib import closing
 from datetime import datetime
 from pathlib import Path
@@ -29,6 +29,9 @@ import torch
 from prettytable import PrettyTable, from_db_cursor
 
 from fastestimator.schedule.schedule import Scheduler
+from fastestimator.summary.logs.log_parse import parse_log_iter
+from fastestimator.summary.logs.log_plot import visualize_logs
+from fastestimator.summary.summary import Summary, average_summaries
 from fastestimator.summary.system import System
 from fastestimator.util.cli_util import SaveAction
 from fastestimator.util.util import NonContext, parse_string_to_python
@@ -220,13 +223,11 @@ class HistoryRecorder:
         self.db_path = db_path if db_path else os.path.join(str(Path.home()), 'fastestimator_data', 'history.db')
         self.system = system
         self.db = None
-        self.ident = (multiprocessing.current_process().pid, threading.get_ident())
         self.pk = None
         self.stdout = None
 
     def __enter__(self) -> None:
         self.db = connect(self.db_path)
-        self.ident = (multiprocessing.current_process().pid, threading.get_ident())
         self.pk = self.system.exp_id  # This might be changed later by RestoreWizard. See the _check_for_restart method
         # Check whether an entry for this pk already exists, for example if a user ran .fit() and is now running .test()
         with closing(self.db.cursor()) as cursor:
@@ -317,6 +318,8 @@ class HistoryRecorder:
         features = []
         if sys.modules['fastestimator'].fe_deterministic_seed is not None:
             features.append({'feature': 'Deterministic', 'fk': self.pk})
+        if any([len(mode_dict) > 1 for mode_dict in self.system.pipeline.data.values()]):
+            features.append({'feature': 'MultiDataset', 'fk': self.pk})
         if mixed_precision.global_policy().compute_dtype == 'float16':
             features.append({'feature': 'MixedPrecision', 'fk': self.pk})
         return features
@@ -328,8 +331,9 @@ class HistoryRecorder:
             A list of entries which can be written into the 'datasets' db table.
         """
         datasets = []
-        for mode, ds in self.system.pipeline.data.items():
-            datasets.append({'mode': mode, 'dataset': type(ds).__name__, 'fk': self.pk})
+        for mode, group in self.system.pipeline.data.items():
+            for _, ds in group.items():
+                datasets.append({'mode': mode, 'dataset': type(ds).__name__, 'fk': self.pk})
         return datasets
 
     def _get_items_in_use(self, items: List[Any]) -> List[Dict[str, str]]:
@@ -372,12 +376,12 @@ class HistoryRecorder:
         self.db.close()
 
     def write(self, output: str) -> None:
+        self._check_for_restart()  # Check here instead of just waiting for __exit__ in case system powers off later
         self.stdout.write(output)
-        if multiprocessing.current_process().pid == self.ident[0] and threading.get_ident() == self.ident[1]:
+        if multiprocessing.current_process().name == 'MainProcess':
             # Flush can also get invoked by pipeline multi-processing, but db should only be accessed by main thread.
             # This can happen, for example, when pipeline prints a warning that a certain key is unused and will be
             # dropped.
-            self._check_for_restart()  # Check here instead of just waiting for __exit__ in case system powers off later
             self.db.execute('UPDATE logs SET log = log || (?) WHERE fk = (?)', [output, self.pk])
             self.db.commit()
 
@@ -547,6 +551,7 @@ class HistoryReader:
         self._configure_sql_parser(subparsers)
         self._configure_log_parser(subparsers)
         self._configure_err_parser(subparsers)
+        self._configure_vis_parser(subparsers)
         try:
             args, unknown = parser.parse_known_args(inp.split())
         except SystemExit:
@@ -613,6 +618,74 @@ class HistoryReader:
                            help="Indices of experiments for which to print error tracebacks")
         p_err.set_defaults(func=self._fetch_errs)
 
+    def _configure_vis_parser(self, subparsers: argparse._SubParsersAction) -> None:
+        """Add a visualization parser to an existing argparser.
+
+        Args:
+            subparsers: The parser object to be appended to.
+        """
+        p_vis = subparsers.add_parser(
+            'vis',
+            description='Visualize logs for one or more experiments. This command requires '
+            'that you currently have experiments selected.',
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+            allow_abbrev=False)
+        p_vis.add_argument('indices',
+                           metavar='idx',
+                           type=int,
+                           nargs='*',
+                           help="Indices of experiments for which to print logs")
+        group = p_vis.add_mutually_exclusive_group()
+        group.add_argument('--ignore',
+                           metavar='I',
+                           type=str,
+                           nargs='+',
+                           help="The names of metrics to ignore though they may be present in the log files")
+        group.add_argument('--include',
+                           metavar='Y',
+                           type=str,
+                           nargs='+',
+                           help="The names of metrics to include. If provided, any other metrics will be ignored.")
+        p_vis.add_argument('--smooth',
+                           metavar='<float>',
+                           type=float,
+                           help="The amount of gaussian smoothing to apply (zero for no smoothing)",
+                           default=1)
+        p_vis.add_argument('--pretty_names', help="Clean up the metric names for display", action='store_true')
+        p_vis.add_argument('-g', '--group', dest='groups', default={}, action=_GroupAction, nargs="*")
+
+        legend_group = p_vis.add_argument_group('legend arguments')
+        legend_x_group = legend_group.add_mutually_exclusive_group(required=False)
+        legend_x_group.add_argument('--common_legend',
+                                    dest='share_legend',
+                                    help="Generate one legend total",
+                                    action='store_true',
+                                    default=True)
+        legend_x_group.add_argument('--split_legend',
+                                    dest='share_legend',
+                                    help="Generate one legend per graph",
+                                    action='store_false',
+                                    default=False)
+
+        save_group = p_vis.add_argument_group('output arguments')
+        save_x_group = save_group.add_mutually_exclusive_group(required=False)
+        save_x_group.add_argument(
+            '--save',
+            nargs='?',
+            metavar='<Save Dir>',
+            dest='save',
+            action=SaveAction,
+            default=False,
+            help="Save the output image. May be accompanied by a directory into \
+                  which the file is saved. If no output directory is specified, the history directory will be used")
+        save_x_group.add_argument('--display',
+                                  dest='save',
+                                  action='store_false',
+                                  help="Render the image to the UI (rather than saving it)",
+                                  default=True)
+        save_x_group.set_defaults(save_dir=None)
+        p_vis.set_defaults(func=self._vis_logs)
+
     @staticmethod
     def _echo_sql(args: Dict[str, Any], unknown: List[str]) -> Optional[str]:
         """A method to compile parsed user input back into a single sql query.
@@ -691,6 +764,58 @@ class HistoryReader:
             else:
                 print(f"No error traceback found for Index {idx}")
 
+    def _vis_logs(self, args: Dict[str, Any], unknown: List[str]) -> None:
+        """A method to collect and visualize a given set of logs from the database.
+
+        Args:
+            args: The CLI arguments provided by the user.
+            unknown: Any CLI arguments not matching known inputs.
+        """
+        if len(unknown) > 0:
+            print("unrecognized arguments: ", str.join(", ", unknown))
+            return
+        save_dir = args['save_dir']
+        if args['save'] and save_dir is None:
+            save_dir = os.path.join(str(Path.home()), 'fastestimator_data', 'logs.png')
+        group_indices = [x for y in args['groups'].values() for x in y]
+        pks = {idx: self.response[idx - 1]['pk'] for idx in set(args['indices'] + group_indices)}
+        if len(pks) == 0:
+            return
+        with closing(self.db.cursor()) as cursor:
+            cursor.execute(
+                "SELECT H.pk, H.experiment, L.log "
+                "FROM logs L LEFT JOIN history H ON L.fk = H.pk "
+                "WHERE L.fk IN ({seq})".format(seq=','.join(['?'] * len(pks))),
+                list(pks.values()))
+            logs = cursor.fetchall()
+        logs = {elem['pk']: elem for elem in logs}
+        failures = 0
+        for idx, pk in pks.items():
+            if pk not in logs:
+                print(f"No logs found for Index {idx}")
+                failures += 1
+        if failures:
+            return
+        groups = defaultdict(list)  # {group_name: [experiment(s)]}
+        for idx, pk in pks.items():
+            log = logs[pk]
+            experiment = parse_log_iter(
+                log['log'].split('\n'),
+                Summary(str(idx) if log['experiment'] is None else f"{log['experiment']} ({idx})"))
+            if idx in args['indices']:
+                groups[experiment.name].append(experiment)
+            for group_name, group_indices in args['groups'].items():
+                if idx in group_indices:
+                    groups[group_name].append(experiment)
+        experiments = [average_summaries(name, exps) for name, exps in groups.items()]
+        visualize_logs(experiments,
+                       save_path=save_dir,
+                       smooth_factor=args['smooth'],
+                       share_legend=args['share_legend'],
+                       pretty_names=args['pretty_names'],
+                       ignore_metrics=args['ignore'],
+                       include_metrics=args['include'])
+
 
 class _GroupAction(argparse._AppendAction):
     """An argparse action which can be invoked multiple times in order to build a dictionary of entries.
