@@ -15,6 +15,7 @@
 import datetime
 import json
 import os
+import uuid
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypeVar, Union
 
 import dill as pickle  # Need to use dill since tf.Variable is a weakref object on multi-gpu machines
@@ -55,6 +56,7 @@ class System:
     Attributes:
         mode: What is the current execution mode of the estimator ('train', 'eval', 'test'), None if warmup.
         ds_id: The current dataset id, None if there is only one dataset in each mode.
+        exp_id: A unique identifier for current training experiment.
         global_step: How many training steps have elapsed.
         num_devices: How many GPUs are available for training.
         log_steps: Log every n steps (0 to disable train logging, None to disable all logging).
@@ -74,6 +76,7 @@ class System:
 
     mode: Optional[str]
     ds_id: Optional[str]
+    exp_id: int
     global_step: Optional[int]
     num_devices: int
     log_steps: Optional[int]
@@ -125,6 +128,8 @@ class System:
         """
         self.global_step = None
         self.epoch_idx = 0
+        # Get a 64 bit random id related to current time
+        self.exp_id = int.from_bytes(uuid.uuid1().bytes, byteorder='big', signed=True) >> 64
 
     def update_global_step(self) -> None:
         """Increment the current `global_step`.
