@@ -17,6 +17,7 @@ from fastestimator.trace.io.csv_logger import CSVLogger
 from fastestimator.trace.io.image_saver import ImageSaver
 from fastestimator.trace.io.image_viewer import ImageViewer
 from fastestimator.trace.io.model_saver import ModelSaver
-from fastestimator.trace.io.qms import QMSTest
 from fastestimator.trace.io.restore_wizard import RestoreWizard
 from fastestimator.trace.io.tensorboard import TensorBoard
+from fastestimator.trace.io.test_report import TestReport
+from fastestimator.trace.io.traceability import Traceability
