@@ -16,7 +16,8 @@ from fastestimator.util.data import Data
 from fastestimator.util.img_data import ImgData
 from fastestimator.util.latex_util import AdjustBox, Center, ContainerList, HrefFEID, PyContainer, Verbatim
 from fastestimator.util.traceability_util import FeSplitSummary, trace_model, traceable
-from fastestimator.util.util import FEID, DefaultKeyDict, Flag, LogSplicer, NonContext, Suppressor, Timer, draw, \
-    get_batch_size, get_num_devices, get_shape, get_type, is_number, pad_batch, pad_data, param_to_range, parse_modes, \
-    parse_string_to_python, prettify_metric_name, show_image, strip_prefix, strip_suffix, to_list, to_number, to_set
+from fastestimator.util.util import FEID, DefaultKeyDict, Flag, LogSplicer, NonContext, Suppressor, Timer, \
+    check_ds_id, check_io_names, draw, get_batch_size, get_num_devices, get_shape, get_type, is_number, pad_batch, \
+    pad_data, param_to_range, parse_modes, parse_string_to_python, prettify_metric_name, show_image, strip_prefix, \
+    strip_suffix, to_list, to_number, to_set
 from fastestimator.util.wget_util import bar_custom, callback_progress
