@@ -12,14 +12,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ==============================================================================
+import os
+import tempfile
 import unittest
 
 import numpy as np
 import tensorflow as tf
 import torch
+from tensorflow_addons.optimizers import SGDW
 
 import fastestimator as fe
-from fastestimator.test.unittest_util import OneLayerTorchModel, is_equal, one_layer_tf_model
+from fastestimator.test.unittest_util import is_equal
 
 
 def get_model_weight_tf(model):
@@ -48,29 +51,41 @@ class TestLoadModelAndSaveModel(unittest.TestCase):
     def test_save_model_and_load_model_tf(self):
         m1 = fe.build(fe.architecture.tensorflow.LeNet, optimizer_fn="adam")
         weight1 = get_model_weight_tf(m1)
-
-        fe.backend.save_model(m1, save_dir="tmp", model_name="test")
+        temp_folder = tempfile.mkdtemp()
+        fe.backend.save_model(m1, save_dir=temp_folder, model_name="test")
 
         m2 = fe.build(fe.architecture.tensorflow.LeNet, optimizer_fn="adam")
         weight2 = get_model_weight_tf(m2)
         self.assertFalse(is_equal(weight1, weight2))
 
-        fe.backend.load_model(m2, weights_path="tmp/test.h5")
+        fe.backend.load_model(m2, weights_path=os.path.join(temp_folder, "test.h5"))
         weight3 = get_model_weight_tf(m2)
 
         self.assertTrue(is_equal(weight1, weight3))
 
+    def test_save_model_and_load_model_tf_optimizer(self):
+        m1 = fe.build(fe.architecture.tensorflow.LeNet,
+                      optimizer_fn=lambda: SGDW(weight_decay=2e-5, learning_rate=2e-4))
+        temp_folder = tempfile.mkdtemp()
+        fe.backend.save_model(m1, save_dir=temp_folder, model_name="test", save_optimizer=True)
+
+        m2 = fe.build(fe.architecture.tensorflow.LeNet,
+                      optimizer_fn=lambda: SGDW(weight_decay=1e-5, learning_rate=1e-4))
+        fe.backend.load_model(m2, weights_path=os.path.join(temp_folder, "test.h5"), load_optimizer=True)
+        self.assertTrue(np.allclose(fe.backend.get_lr(model=m2), 2e-4))
+        self.assertTrue(np.allclose(tf.keras.backend.get_value(m2.current_optimizer.weight_decay), 2e-5))
+
     def test_save_model_and_load_model_torch(self):
         m1 = fe.build(fe.architecture.pytorch.LeNet, optimizer_fn="adam")
         weight1 = get_model_weight_lenet_torch(m1)
-
-        fe.backend.save_model(m1, save_dir="tmp", model_name="test")
+        temp_folder = tempfile.mkdtemp()
+        fe.backend.save_model(m1, save_dir=temp_folder, model_name="test")
 
         m2 = fe.build(fe.architecture.pytorch.LeNet, optimizer_fn="adam")
         weight2 = get_model_weight_lenet_torch(m2)
         self.assertFalse(is_equal(weight1, weight2))
 
-        fe.backend.load_model(m2, weights_path="tmp/test.pt")
+        fe.backend.load_model(m2, weights_path=os.path.join(temp_folder, "test.pt"))
         weight3 = get_model_weight_lenet_torch(m2)
 
         self.assertTrue(is_equal(weight1, weight3))
